@@ -140,9 +140,9 @@ class ListResource(Resource):
         # Lookup by SID
         else:
             if self._populated:
-                for item in self._resource_data:
+                for item in self._resource_data[self._short_name]:
                     if item["sid"] == key:
-                        return _name_to_instance_class(self._name)(parent=self, fetched_data=nth_item)
+                        return _name_to_instance_class(self._name)(parent=self, fetched_data=item)
             else:
                 return _name_to_instance_class(self._name)(parent=self, sid=key)
 
@@ -226,6 +226,9 @@ class ListResource(Resource):
 
         return self
 
+    def __repr__(self):
+        self.fetch()
+        return str(self._resource_data)
 
 
 
@@ -349,6 +352,9 @@ class InstanceResource(Resource):
 
         return None
 
+    def __repr__(self):
+        self.fetch()
+        return str(self._resource_data)
 
 
 
